"""nutri-matic Package

© All rights reserved. Jared Cook

See the LICENSE file for more details.

Author: Jared Cook
"""

from .verbose import verbose_mode
from .version import version_mode

__all__ = [
    "verbose_mode",
    "version_mode",
]
