"""nutri-matic Package

© All rights reserved. Jared Cook

See the LICENSE file for more details.

Author: Jared Cook
"""

from .ansible import generate_ansible_dirs
from .docs import generate_docs_templates

__all__ = ["generate_ansible_dirs", "generate_docs_templates"]
